@@ -221,6 +221,39 @@ func TestNew(t *testing.T) {
 			path:       "",
 			wantE:      nil,
 		},
+		{
+			name:       "ipv6 localhost address registry",
+			ref:        "[::1]:5000/image:v42",
+			scheme:     "reg",
+			registry:   "[::1]:5000",
+			repository: "image",
+			tag:        "v42",
+			digest:     "",
+			path:       "",
+			wantE:      nil,
+		},
+		{
+			name:       "ipv6 address registry",
+			ref:        "[fddd:1222:1222:1222::ac29:5a6a]:5000/image:v42",
+			scheme:     "reg",
+			registry:   "[fddd:1222:1222:1222::ac29:5a6a]:5000",
+			repository: "image",
+			tag:        "v42",
+			digest:     "",
+			path:       "",
+			wantE:      nil,
+		},
+		{
+			name:       "ipv6 address registry without port",
+			ref:        "[fddd:1222:1222:1222::ac29:5a6a]/image:v42",
+			scheme:     "reg",
+			registry:   "[fddd:1222:1222:1222::ac29:5a6a]",
+			repository: "image",
+			tag:        "v42",
+			digest:     "",
+			path:       "",
+			wantE:      nil,
+		},
 		{
 			name:       "Port registry digest",
 			ref:        "registry:5000/group/image@" + testDigest,
@@ -329,6 +362,16 @@ func TestNew(t *testing.T) {
 			ref:   "docker-.io/project/image:tag",
 			wantE: errs.ErrInvalidReference,
 		},
+		{
+			name:  "invalid ipv6 compression",
+			ref:   "[1::2::3]/project/image:tag",
+			wantE: errs.ErrInvalidReference,
+		},
+		{
+			name:  "invalid ipv6 missing brackets",
+			ref:   "::1/project/image:tag",
+			wantE: errs.ErrInvalidReference,
+		},
 		{
 			name:  "invalid repo case",
 			ref:   "docker.io/Upper/Case/Repo:tag",
@@ -521,6 +564,30 @@ func TestNewHost(t *testing.T) {
 			path:     "",
 			wantE:    nil,
 		},
+		{
+			name:     "ipv6 compressed address registry",
+			host:     "[::1]:5000",
+			scheme:   "reg",
+			registry: "[::1]:5000",
+			path:     "",
+			wantE:    nil,
+		},
+		{
+			name:     "ipv6 address registry",
+			host:     "[fddd:1222:1222:1222::ac29:5a6a]:5000",
+			scheme:   "reg",
+			registry: "[fddd:1222:1222:1222::ac29:5a6a]:5000",
+			path:     "",
+			wantE:    nil,
+		},
+		{
+			name:     "ipv6 address registry without port",
+			host:     "[fddd:1222:1222:1222::ac29:5a6a]",
+			scheme:   "reg",
+			registry: "[fddd:1222:1222:1222::ac29:5a6a]",
+			path:     "",
+			wantE:    nil,
+		},
 		{
 			name:     "OCI file",
 			host:     "ocifile://path",
@@ -589,6 +656,16 @@ func TestNewHost(t *testing.T) {
 			host:  "docker-.io",
 			wantE: errs.ErrParsingFailed,
 		},
+		{
+			name:  "invalid ipv6 compression",
+			host:  "[1::2::3]:5000",
+			wantE: errs.ErrParsingFailed,
+		},
+		{
+			name:  "invalid ipv6 missing brackets",
+			host:  "::1:5000",
+			wantE: errs.ErrParsingFailed,
+		},
 	}
 
 	for _, tc := range tt {
